@@ -27,20 +27,16 @@ def setOutput(self, msg:str) -> None:
 def addOne(num:int) -> int:
     return num+1
 
-# def band():
-#     main_window_signal.appendOutPutBox.connect(appendOutPut)
+STRING=(1<<0)
+NUM=(1<<1)
+FLOAT=(1<<2)
+LIST=(1<<3)
+ON=(1<<1)
+OFF=(1<<0)
 
-#     main_window_signal.setOutPutBox.connect(setOutPut)
-
-#     main_window_signal.clearOutPutBox.connect(clearOutPut)
-
-# def appendOutPut(self, msg:str):
-#     self.ui.output_box.appendPlainText(msg)
-
-# def clearOutPut(self):
-#     self.ui.output_box.clear()
-
-# def setOutPut(self, msg:str):
-#     self.ui.output_box.setPlainText(msg)
-
-# band()
\ No newline at end of file
+#'output_mode'
+RETURN_ONCE=(1<<0)
+RETURN_LIST=(1<<1)
+RETURN_LIST_OUTPUT_IN_ONE_LINE=(1<<2)
+NO_RETURN=(1<<3)
+NO_RETURN_SINGLE_FUNCTION=(1<<4)
\ No newline at end of file
